% [y,x] = euler(f,a,ya,n);
% Eksplicitna Eulerjeva metoda za resevanje zacetnega problema y'=f(x,y), y(x0)=y0.
% Vhod:
% f : funkcija f(x,y) -- desna stran diferencialne enacbe y'=f(x,y)
% a : interval [a, b] na katerem iscemo numericno resitev
% ya : vektor zacetnih pogojev v levem krajiscu
% n : stevilo podintervalov danega intervala
% Izhod:
% x : delitev intervala [a, b]
% y : matrika vrednosti funkcije y(x) v notranjih tockah intervala in na robu
function [y,x] = euler(f,a,ya,n);
  h = (a(2)-a(1))/n;
  y = zeros(length(ya),n+1);
  y(:,1) = ya(:);
  x = linspace(a(1),a(2),n+1);				 
  for i = 2:n+1
    y(:,i) = y(:,i-1)+h*f(x(i-1),y(:,i-1));
  end;